sub_paths = {
    "sources": "release/config/wv.json/sources.json",
    "features": "common/features.json",
    "layer_order": "common/config/wv.json/layerOrder.json",
    "measurements": "common/config/wv.json/measurements",
    "disciplines": "common/config/wv.json/categories/science_disciplines",
}
